@@ -9,7 +9,9 @@ __author__  = ''
 __docformat__ = 'restructuredtext'
 
 import zope.component
+import zope.interface
 from zope.component.factory import Factory
+from iw.email import interfaces
 from email.MIMEMultipart import MIMEMultipart
 from email.MIMEText import MIMEText
 from email.MIMEImage import MIMEImage
@@ -18,18 +20,33 @@ from email import Header
 from time import strftime
 from time import localtime
 import types
+import os
 
-from utils import safe_unicode
+from iw.email.utils import safe_unicode
 
 
 class MultipartMail(object):
     """Provide a clean way to generate an email
-
     """
+    zope.interface.implements(interfaces.IMail)
 
     def __init__(self, html=None, text=None, mfrom=None, mto=None, subject=''):
+        """Verify thats mfrom and mto are required::
+
+            >>> from iw.email.mail import MultipartMail
+            >>> MultipartMail(mfrom='gael@ingeniweb.com')
+            Traceback (most recent call last):
+            ...
+            ValueError: Emails invalid: mfrom: "'gael@ingeniweb.com'", mto: "None"
+
+            >>> MultipartMail(mto='gael@ingeniweb.com')
+            Traceback (most recent call last):
+            ...
+            ValueError: Emails invalid: mfrom: "None", mto: "'gael@ingeniweb.com'"
+        """
         if not mfrom or not mto:
-            raise ValueError('Emails invalid: %s %s' % (mfrom, mto))
+            raise ValueError(
+                    'Emails invalid: mfrom: "%r", mto: "%r"' % (mfrom, mto))
         if not text and not html:
             raise ValueError('You must give at least one mail content')
         self.text = text
@@ -43,17 +60,29 @@ class MultipartMail(object):
         self.images = []
 
     def addImage(self, image, filename='', content_type=''):
-        """
+        """add an image
         """
         if not filename:
             if hasattr(image, 'getId'):
                 filename = image.getId()
             else:
-                raise RuntimeError('You must give a filename or an object with a getId method')
+                raise RuntimeError(
+                        'You must give a filename'
+                        ' or an object with a getId method')
         if not content_type:
             if hasattr(image, 'getContentType'):
                 content_type = image.getContentType()
-                raise RuntimeError('You must give a filename or an object with a getContentType method')
+            elif filename:
+                x, ext = os.path.splitext(filename.lower())
+                if ext in ('.jpg',):
+                    content_type = 'image/jpeg'
+                if ext in ('.gif', '.png'):
+                    content_type = 'image/%s' % ext[1:]
+
+        if not content_type:
+            raise RuntimeError(
+                    'You must give a filename'
+                    ' or an object with a getContentType method')
 
         #get data
         if hasattr(image, 'read'):
@@ -72,10 +101,9 @@ class MultipartMail(object):
         subtype = content_type.split('/')[1]
         image = MIMEImage(data, subtype, name=filename)
         image.add_header('Content-ID', '<%s>' % filename)
-        #image.add_header('Content-Disposition', 'attachment; filename="%s"' % name)
         self.images.append(image)
 
-    def __str__(self):
+    def as_string(self, unixfrom=True):
 
         if type(self.subject) != types.UnicodeType:
             self.subject = unicode(self.subject, self.in_charset)
@@ -106,9 +134,13 @@ class MultipartMail(object):
         for image in self.images:
             related.attach(image)
 
-        return related.as_string(unixfrom=False)
+        return related.as_string(unixfrom=unixfrom)
+
+    __call__ = as_string
+
+    def __str__(self):
+        return self.as_string(unixfrom=False)
 
-    __call__ = __str__
 
 MultipartMailFactory = Factory(MultipartMail, 'MultipartMail', '')
 
