@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import os
+import sys
 import smtplib
 
 TEST_MAIL = None
@@ -23,12 +24,15 @@ else:
             smtplib.SMTP().sendmail(mfrom, mto, str(messageText))
             return 'fake-message-id@example.com'
 
-def smtpSetUp(*args):
+def smtpSetUp(*args, **kwargs):
     if TEST_MAIL:
         server = smtplib.SMTP(TEST_MAILHOST, int(TEST_MAILPORT))
 
+    fd = kwargs.get('fd', None)
+
     smtplib.SMTP._old___init__ = smtplib.SMTP.__init__
     smtplib.SMTP._old_sendmail = smtplib.SMTP.sendmail
+    smtplib.SMTP._old_close = smtplib.SMTP.close
 
     def __init__(self, *args, **kwargs):
         """patch __init__"""
@@ -38,10 +42,19 @@ def smtpSetUp(*args):
         """patche sendmail"""
         if TEST_MAIL:
             server._old_sendmail(TEST_MAILFROM, TEST_MAIL, str(message))
-        print message
+        if 'fd' in kwargs and callable(fd):
+            print >> fd(), message
+        else:
+            print message
     smtplib.SMTP.sendmail = sendmail
 
+    def close(self):
+        """do nothing
+        """
+    smtplib.SMTP.close = close
+
 def smtpTearDown(*args):
     smtplib.SMTP.__init__ = smtplib.SMTP._old___init__
     smtplib.SMTP.sendmail = smtplib.SMTP._old_sendmail
+    smtplib.SMTP.close = smtplib.SMTP._old_close
 
